aggregate break even: priorities: [ ] perhaps a version that is exclusively about the ask price, and doesn't care about "open interest" A version like this would essentially show how expensive the options contracts are. formulas [ for every contract, for every call, for every put, for every call at an expiration, for every put at an expiration, ] summation (contract price * break even * open interest * shares per contract) --- summation (contract price * open interest * shares per contract) description aggregates the break even value